@@ -5,14 +5,21 @@ from ctypes.wintypes import DWORD, HWND, ULONG
 from enum import Enum
 from typing import Literal
 
-
 from tkdev.devicon import Icon_Empty, Icon_Folder, Icon_Info, Icon_Error, Icon_Warring, Icon_Question, Icon_Questhead, \
     Icon_Hourglass, Icon_QuickFish, Icon_TkinterDev
 from tkdev.devresize import DevResize
 from tkdev.devcore import DevAction, DevSysTray
 from tkdev.devdraw import DrawButton
 from tkdev.devpre import DevPreToolbox
-from tkdev.winico import DevTray, WM_EVENT, download_winico
+from tkdev.winico import (DevTray, WM_EVENT, download_winico,
+                          WM_RBUTTONDOWN, WM_RBUTTONUP, WM_RBUTTONDBLCLK,
+                          WM_LBUTTONDOWN, WM_LBUTTONUP, WM_LBUTTONDBLCLK,
+                          WM_MBUTTONDOWN, WM_MBUTTONUP, WM_MBUTTONDBLCLK,
+                          WM_MOUSEMOVE,
+                          ICON_APPLICATION, ICON_ASTERISK, ICON_INFORMATION,
+                          ICON_EXCLAMATION, ICON_WINLOGO, ICON_HAND,
+                          ICON_ERROR, ICON_WARNING, ICON_QUESTION,
+                          ICON_MODE_ICON, ICON_MODE_LOAD, ICON_MODE_NONE)
 import warnings
 
 try:
@@ -52,7 +59,6 @@ DWMWA_USE_IMMERSIVE_DARK_MODE = 20
 
 
 def AddShortCut(File, Link="link.lnk", Path: str = ".//"):
-
     """
     给文件添加一个快捷键到指定位置
 
@@ -86,7 +92,6 @@ def AutoStart(File: str, Name: str = "Application"):
 
 
 def Package(File, Ofter="-w", StartMenu: bool = True):
-
     """
     用于打包Python文件。
     """
@@ -99,26 +104,26 @@ def Package(File, Ofter="-w", StartMenu: bool = True):
     import os
     import os.path
 
-    os.system(os.path.split(sys.executable)[0]+f"\\Scripts\\pyinstaller.exe {Ofter} {File}")
+    os.system(os.path.split(sys.executable)[0] + f"\\Scripts\\pyinstaller.exe {Ofter} {File}")
 
     if StartMenu:
         from getpass import getuser
         print("asdas")
         name = os.path.splitext(os.path.split(File)[1])[0]
         print(name)
-        if os.path.exists("dist\\"+name+".exe"):
-            path = "dist\\"+name+".exe"
-        elif os.path.exists("dist\\"+name+"\\"+name+".exe"):
-            path = "dist\\"+name+"\\"+name+".exe"
+        if os.path.exists("dist\\" + name + ".exe"):
+            path = "dist\\" + name + ".exe"
+        elif os.path.exists("dist\\" + name + "\\" + name + ".exe"):
+            path = "dist\\" + name + "\\" + name + ".exe"
         print(path)
         print(os.getcwd())
         from win32com.client import Dispatch
         from shutil import move
         Shell = Dispatch("WScript.Shell")
-        ShortCut = Shell.CreateShortCut(name+".lnk")
-        ShortCut.TargetPath = os.getcwd()+"\\"+path
+        ShortCut = Shell.CreateShortCut(name + ".lnk")
+        ShortCut.TargetPath = os.getcwd() + "\\" + path
         ShortCut.save()
-        move(name+".lnk", f"C:\\Users\\{getuser()}\\AppData\\Roaming\\Microsoft\\Windows\\Start Menu\\Programs")
+        move(name + ".lnk", f"C:\\Users\\{getuser()}\\AppData\\Roaming\\Microsoft\\Windows\\Start Menu\\Programs")
 
 
 def UpGrade(Library, Basic: bool = True, Preview: bool = False, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
@@ -261,6 +266,7 @@ def window_move(widget: tk.Widget, window: tk.Tk):
     :param widget: 为使窗口移动的组件
     :param window: 为被移动的窗口
     """
+
     def move(evt):
         ReleaseCapture()
         SendMessage(GetParent(window.winfo_id()), WM_SYSCOMMAND,
@@ -308,6 +314,7 @@ def window_long(window: tk.Tk, long):
     :param window: 为设置的组件
     :param long: 为设置的参数
     """
+
     def long():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~long)
@@ -419,6 +426,7 @@ def window_sizebox(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def sizebox():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_SIZEBOX)
@@ -432,6 +440,7 @@ def window_maxbox(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def max():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_MAXIMIZEBOX)
@@ -445,6 +454,7 @@ def window_minbox(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def min():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_MINIMIZEBOX)
@@ -458,6 +468,7 @@ def window_grayed_closebox(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def close():
         hwnd = GetParent(window.winfo_id())
         res = EnableMenuItem(GetSystemMenu(hwnd, False), SC_CLOSE, MF_BYCOMMAND | MF_GRAYED)
@@ -471,6 +482,7 @@ def window_enabled_closebox(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def close():
         hwnd = GetParent(window.winfo_id())
         res = EnableMenuItem(GetSystemMenu(hwnd, False), SC_CLOSE, MF_BYCOMMAND | MF_ENABLED)
@@ -484,6 +496,7 @@ def window_popup(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def popup():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_POPUPWINDOW)
@@ -497,6 +510,7 @@ def window_custom_taskbar(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def over():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_OVERLAPPEDWINDOW)
@@ -512,6 +526,7 @@ def window_custom_border_taskbar(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def custom():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_BORDER)
@@ -539,6 +554,7 @@ def window_border(window: tk.Tk):
 
     :param window: 为设置的组件。
     """
+
     def border():
         hWnd = GetParent(window.winfo_id())
         SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
@@ -556,6 +572,7 @@ def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
     :param toplevel: 设置为嵌入的窗口
     :param iswindow: 确认容器是否使窗口
     """
+
     def embed():
         SetParent(GetParent(toplevel.winfo_id()), window.winfo_id())
         toplevel.deiconify()
@@ -605,7 +622,7 @@ def Error(text):
     except ImportError:
         print(text)
     else:
-        print(Fore.RED+text+Fore.RESET)
+        print(Fore.RED + text + Fore.RESET)
 
 
 class DevAccumulatorButton(tk.Button):
@@ -853,6 +870,25 @@ class DevHeaderBar(tk.Frame):
                                          command=self.minimize)
         self.minimize_button.pack(side=tk.RIGHT, ipady=2, ipadx=12, fill=tk.Y)
 
+    def add_icon(self, icon=Icon_TkinterDev, background="#ffffff", ):
+        self.icon = tk.Label(self, image=tk.PhotoImage(icon), background=background)
+        self.icon.pack(fill=tk.Y, side=tk.LEFT, padx=10)
+
+    def add_title(self, text="", font=("微软雅黑", 9),
+                  background="#ffffff", foreground="#000000"):
+        """
+        为标题栏添加最小化按钮，
+
+        :param text: 为标题的文本
+        :param font: 为标题的字体
+        :param background: 为标题的背景颜色
+        :param foreground: 为标题的前景颜色
+        """
+        self.title = tk.Label(self, text=text, font=font,
+                              background=background, foreground=foreground)
+        self.master.title(text)
+        self.title.pack(fill=tk.Y, side=tk.LEFT, padx=10)
+
     def maximize_event(self):
         """
         内置函数，使窗口最大化
@@ -891,6 +927,9 @@ class DevImage(tk.Label):
 
 class DevNotifyIcon(object):
     def __init__(self, master: tk.Tk, tip: str = "托盘图标", icon=Icon_Folder):
+        """
+        正在开发，请不要使用
+        """
         import os.path
         self._hWnd = GetParent(master.winfo_id())
         self._icon = icon
@@ -933,7 +972,6 @@ class DevNotifyIcon(object):
     def add(self):
         Shell_NotifyIcon(NIM_ADD, self._notify_id)
 
-
     def delete(self):
         Shell_NotifyIcon(NIM_DELETE, self._notify_id)
 
@@ -1046,25 +1084,50 @@ class DevBorder(object):
 
 class DevStack(tk.Frame):
     def __init__(self):
+        """
+        用于切换不同的界面
+        """
         super(DevStack, self).__init__()
         self._pages = {}
 
     def add_page(self, page: tk.Widget, id: int = 0):
+        """
+        添加页面
+        
+        :param page: 页面组件
+        :param id: 组件ID
+        """
         self._pages[id] = page
 
     def show_page(self, id: int):
+        """
+        显示页面，会将其他页面隐藏
+        
+        :param id: 被显示的页面ID
+        """
         self._pages[id].pack(fill=tk.BOTH, expand=tk.YES)
         for item in self._pages.keys():
             if not item == id:
                 self.hide_page(item)
-                print("Hide" + str(item))
-            else:
-                print("Show" + str(item))
 
     def hide_page(self, id: int):
+        """
+        内置函数，最好不要使用，因为几乎没有什么用
+        """
         self._pages[id].pack_forget()
 
+    def get_page(self, id: int):
+        """
+        获取页面
+        
+        :param id: 所要获取的页面ID
+        """
+        return self._pages[id]
+
     def get_pages(self):
+        """
+        获取所有页面
+        """
         return self._pages
 
 
@@ -1142,13 +1205,21 @@ class DevToast(tk.Toplevel):
         self.after(5000, self.withdraw)
 
 
-class DevTabber(tk.Frame):
+class DevTabbar(tk.Frame):
     def __init__(self, master: tk.Widget):
-        super(DevTabber, self).__init__(master=master)
+        """
+        工具栏
+
+        :param master: 父组件
+        """
+        super(DevTabbar, self).__init__(master=master)
         self.actions = {}
         self.actions_button = {}
 
     def add_action(self, name: str, action: DevAction, use_ttk: bool = False) -> tk.Widget:
+        """
+        添加DevAction组件
+        """
         self.actions[name] = action
         if use_ttk:
             self.actions_button[name] = ttk.Button(self, text=action.text, image=action.icon, command=action.command)
@@ -1161,15 +1232,33 @@ class DevTabber(tk.Frame):
         return self.actions_button[name]
 
     def show(self):
+        """
+        快速显示窗口
+        """
         self.pack(fill=tk.X, side=tk.BOTTOM)
 
     def remove_action(self, name: str):
+        """
+        移除action
+
+        :param name: 移除action的名称
+        """
         self.actions_button[name].forget()
 
     def get_action(self, name: str):
+        """
+        获取action
+
+        :param name: 获取action的名称
+        """
         return self.actions[name]
 
     def get_action_button(self, name: str):
+        """
+        获取action生成的按钮
+
+        :param name: 获取action的名称
+        """
         return self.actions_button[name]
 
 
@@ -1319,6 +1408,52 @@ class DevWindow(tk.Tk):
         """
         self.state("iconic")
 
+    def create_tray(self, tooltip: str = "", install_winico: bool = True):
+        """
+        快速创建系统托盘图标，返回托盘组件
+
+        :param tooltip: 设置托盘图标的提示文本
+        :param install_winico: 如果未检测到winico安装，将会自动进行安装
+        """
+        return DevTray(self, text=tooltip, icon=ICON_APPLICATION, icon_mode=ICON_MODE_LOAD, auto_install=install_winico)
+
+    def create_tray_with_show(self, tooltip: str = "", install_winico: bool = True):
+        """
+        快速创建系统托盘图标，并显示，返回托盘组件和托盘ID
+
+        :param tooltip: 设置托盘图标的提示文本
+        :param install_winico: 如果未检测到winico安装，将会自动进行安装
+        """
+        tray = self.create_tray(tooltip=tooltip, install_winico=install_winico)
+        return tray, tray.show()
+
+    def create_titlebar(self, title: str = "", border: bool = True, double_max: bool = True):
+        """
+        快速创建标题，返回标题栏组件
+
+        :param title: 设置标题栏标题。
+        :param border: 自定义窗口是否又边框。
+        :param double_max: 设置是否可以通过双击放大窗口。
+        """
+        titlebar = DevHeaderBar(self, border=border, double_max=double_max)
+        titlebar.add_title(title)
+        titlebar.add_close_button()
+        titlebar.add_maximize_button()
+        titlebar.add_minimize_button()
+        return titlebar
+
+    def create_titlebar_with_show(self, title: str = "", border: bool = True, double_max: bool = True):
+        """
+        快速创建标题，并使用，返回标题栏组件
+
+        :param title: 设置标题栏标题。
+        :param border: 自定义窗口是否又边框。
+        :param double_max: 设置是否可以通过双击放大窗口。
+        """
+        titlebar = self.create_titlebar(title=title, border=border, double_max=double_max)
+        self.titlebar(titlebar)
+        return titlebar
+
     def dpi(self):
         """
         设置dpi高清晰度
@@ -1427,6 +1562,5 @@ class DevTooltip(DevToplevel):
 
 if __name__ == '__main__':
     Window = DevWindow()
-    NotifyIcon = DevNotifyIcon(Window)
-    NotifyIcon.add()
+    Window.create_titlebar_with_show(title="Hello")
     Window.mainloop()
