@@ -33,6 +33,10 @@ ICON_MODE_NONE = "none"
 
 ICONS = ("application", "asterisk", "error", "exclamation", "hand", "question", "information", "warning", "winlogo")
 
+ID_ADD = "add"
+ID_MODIFY = "modify"
+ID_DELETE = "delete"
+
 
 def download_winico():
     """
@@ -85,8 +89,43 @@ def download_winico():
     shutil.rmtree(tcl + 'Winico64\\')
 
 
+def example_func(event=None, icon_id=None, icon=None, x=None, y=None, window: tkinter.Tk = None):
+    """
+    示例函数
+    """
+    if event == WM_LBUTTONDOWN:
+        window.deiconify()
+    elif event == WM_RBUTTONDOWN:
+        def close():
+            icon.delete(icon_id)
+            window.destroy()
+
+        menu = tkinter.Menu(tearoff=False)
+        menu.add_command(label="发送“Hello”到控制台", command=lambda: print("Hello"), activebackground="#3369d6")
+        menu.add_separator()
+        menu.add_command(label="退出应用程序", command=lambda: close(), activebackground="#3369d6")
+        menu.tk_popup(x, y)
+
+
+def example():
+    """
+    示例
+    """
+    Window = tkinter.Tk()
+    Window.protocol("WM_DELETE_WINDOW", lambda: Window.withdraw())
+    Tray = DevTray(Window, "示例", icon=ICON_APPLICATION, icon_mode=ICON_MODE_LOAD,
+                   menu_func=lambda event=None, icon_id=None, icon=None, x=None, y=None: example_func(event=event,
+                                                                                                      icon_id=icon,
+                                                                                                      icon=Tray, x=x,
+                                                                                                      y=y,
+                                                                                                      window=Window))
+    Tray.taskbar(id="add")
+    Window.mainloop()
+
+
 class DevTray(object):
-    def __init__(self, master: tkinter.Tk, text: str = "托盘图标", icon=None, icon_mode="none", menu_func=None, use_winico: bool = True, auto_install: bool = True):
+    def __init__(self, master: tkinter.Tk, text: str = "托盘图标", icon=None, icon_mode="none", menu_func=None,
+                 use_winico: bool = True, auto_install: bool = True):
         """
         使用tcl扩展winico制作的托盘图标组件。
 
@@ -253,7 +292,7 @@ class DevTray(object):
         :param id: 默认是add，其他选项还有modify和delete
         """
         self._master.tk.call('winico', 'taskbar', id, self._icon,
-                             '-callback', (self._master.register(self._menu_func), '%m', '%i', '%x', '%y'),
+                             '-callback', (self._master.register(self._menu_func), '%m', '%i', self, '%x', '%y'),
                              '-pos', 0,
                              '-text', self._text)
 
@@ -301,7 +340,7 @@ class DevTray(object):
         """
         return self._master.tk.call("winico", "delete", id)
 
-    def menu(self, event, icon, x, y):
+    def menu(self, event, icon_id, icon, x, y):
         """
         内置菜单，用于初始化。
         """
@@ -312,8 +351,4 @@ class DevTray(object):
 
 
 if __name__ == '__main__':
-    Window = tkinter.Tk()
-    Tray = DevTray(Window, "icon")
-    Tray.icon = Tray.information()
-    Tray.taskbar()
-    Window.mainloop()
\ No newline at end of file
+    example()
